@@ -449,9 +449,9 @@ def bg_mod(source, q=None, aper_lc=None, psf_lc=None, portion=None, star_num=0,
     if np.isnan(cal_aper_lc).all():
         print('Calibrated aperture flux are not accessible or processed incorrectly. ')
     else:
-        _, trend = flatten(source.time, cal_aper_lc - np.min(cal_aper_lc) + 1000,
+        _, trend = flatten(source.time, cal_aper_lc - np.nanmin(cal_aper_lc) + 1000,
                                     window_length=1, method='biweight', return_trend=True)
-        cal_aper_lc = (cal_aper_lc - np.min(cal_aper_lc) + 1000 - trend) / np.median(cal_aper_lc) + 1
+        cal_aper_lc = (cal_aper_lc - np.nanmin(cal_aper_lc) + 1000 - trend) / np.nanmedian(cal_aper_lc) + 1
         # cal_aper_lc = flatten(source.time, cal_aper_lc, window_length=1, method='biweight',
         #                       return_trend=False)
     if near_edge:
@@ -463,9 +463,9 @@ def bg_mod(source, q=None, aper_lc=None, psf_lc=None, portion=None, star_num=0,
         if np.isnan(cal_psf_lc).all():
             print('Calibrated PSF flux are not accessible or processed incorrectly. ')
         else:
-            _, trend = flatten(source.time, cal_psf_lc - np.min(cal_psf_lc) + 1000,
+            _, trend = flatten(source.time, cal_psf_lc - np.nanmin(cal_psf_lc) + 1000,
                                          window_length=1, method='biweight', return_trend=True)
-            cal_psf_lc = (cal_psf_lc - np.min(cal_psf_lc) + 1000 - trend) / np.median(cal_psf_lc) + 1
+            cal_psf_lc = (cal_psf_lc - np.nanmin(cal_psf_lc) + 1000 - trend) / np.nanmedian(cal_psf_lc) + 1
             # cal_psf_lc = flatten(source.time, cal_psf_lc, window_length=1, method='biweight',
             #                      return_trend=False)
     # aper_mad = 1.4826 * np.nanmedian(np.abs(cal_aper_lc - 1))
