@@ -125,7 +125,7 @@ def background_mask(im=None):
         _ok = ok[:, i] * ok[:, i + di]
         coef = np.median(im[:, i + di][_ok] / im[:, i][_ok])
         if 0.5 < coef < 2:
-            running_factor *= coef
+            running_factor *= coef543
             cal_factor[i + di] = running_factor
             i += di
             di = 1  # Reset the stepsize to one.
@@ -192,7 +192,7 @@ class Source(object):
         catalog_3 = self.search_gaia(x, y, co2, co1)
         catalog_4 = self.search_gaia(x, y, co2, co2)
         catalogdata = vstack([catalog_1, catalog_2, catalog_3, catalog_4], join_type='exact')
-        catalogdata = unique(catalogdata, keys='designation')
+        catalogdata = unique(catalogdata, keys='DESIGNATION')
         coord = wcs.pixel_to_world([x + (size - 1) / 2 + 44], [y + (size - 1) / 2])[0].to_string()
         ra = float(coord.split()[0])
         dec = float(coord.split()[1])
@@ -211,7 +211,7 @@ class Source(object):
         y_gaia = np.zeros(num_gaia)
         tess_mag = np.zeros(num_gaia)
         in_frame = [True] * num_gaia
-        for i, designation in enumerate(catalogdata['designation']):
+        for i, designation in enumerate(catalogdata['DESIGNATION']):
             ra = catalogdata['ra'][i]
             dec = catalogdata['dec'][i]
             if not np.isnan(catalogdata['pmra'].mask[i]):  # masked?
@@ -352,7 +352,7 @@ def ffi(ccd=1, camera=1, sector=1, size=150, local_directory='', producing_mask=
         if wcs.axis_type_names == ['RA', 'DEC']:
             break
 
-    exposure = int((hdul[0].header['TSTART'] - hdul[0].header['TSTOP']) * 86400)
+    exposure = int((hdul[0].header['TSTOP'] - hdul[0].header['TSTART']) * 86400)
 
     # 95*95 cuts with 2 pixel redundant, (22*22 cuts)
     # try 77*77 with 4 redundant, (28*28 cuts)
